@@ -70,6 +70,10 @@ POS_RIGHT = 1
 POS_TOP = 2
 PREVIEW_COLOR = 0
 PREVIEW_GRAYSCALE = 1
+PRIORITY_HIGH = -20
+PRIORITY_INTERNAL = -10
+PRIORITY_DEFAULT = 0
+PRIORITY_LOW = 10
 #PROPAGATE_STATE = 16384
 RC_STYLE = 262144
 REALIZED = 64
@@ -146,6 +150,9 @@ UPDATE_DISCONTINUOUS = 1
 UPDATE_IF_VALID = 2
 UPDATE_SNAP_TO_TICKS = 4
 #USER_STYLE = 131072
+VISIBILITY_NONE = 0
+VISIBILITY_PARTIAL = 1
+VISIBILITY_FULL = 2
 VISIBLE = 256
 WINDOW_DIALOG = 1
 WINDOW_POPUP = 2
