@@ -48,7 +48,9 @@ class GtkObject:
 			v = v._o
 		_gtk.gtk_object_set(self._o, {key: v});
 	def __cmp__(self, other):
-		return cmp(self._o, other._o)
+		if hasattr(other, '_o'):
+			return cmp(self._o, other._o)
+		return cmp(id(self), id(other))
 	def flags(self, mask=None):
 		if mask:
 			return _gtk.GTK_OBJECT_FLAGS(self._o) & mask
@@ -236,6 +238,8 @@ class GtkWidget(GtkObject):
 		_gtk.gtk_widget_show(self._o)
 	def show_all(self, obj=None):
 		_gtk.gtk_widget_show_all(self._o)
+	def show_now(self, obj=None):
+	        _gtk.gtk_widget_show_now(self._o)
 	def size_allocate(self, a):
 		_gtk.gtk_widget_size_allocate(self._o, a)
 	def size_request(self, r):
@@ -625,6 +629,8 @@ class GtkCombo(GtkHBox):
 	def __init__(self, _obj=None):
 		if _obj: self._o = _obj; return
 		self._o = _gtk.gtk_combo_new()
+	def disable_activate(self, obj=None):
+		_gtk.gtk_combo_disable_activate(self._o)
 	def set_use_arrows(self, val):
 		_gtk.gtk_combo_set_use_arrows(self._o, val)
 	def set_use_arrows_always(self, val):
@@ -1180,6 +1186,8 @@ class GtkText(GtkEditable):
 			self._o = _gtk.gtk_text_new(hadj._o, vadj._o)
 	def set_editable(self, editable):
 		_gtk.gtk_text_set_editable(self._o, editable)
+	def set_word_wrap(self, word_wrap):
+		_gtk.gtk_text_set_word_wrap(self._o, word_wrap)
 	def set_adjustments(self, hadj, vadj):
 		_gtk.gtk_text_set_adjustments(self._o, hadj._o, vadj._o)
 	def get_hadjustment(self):
