@@ -272,7 +272,7 @@ def make_toolbar(win):
 
 		entry = GtkEntry()
 		entry.show()
-		toolbar.append_widget(entry, "")
+		toolbar.append_widget(entry, "", "")
 
 		toolbar.append_space()
 		toolbar.append_item("Small", "Use small spaces",
